@@ -1,7 +1,6 @@
 package Gapp;
-{
-  $Gapp::VERSION = '0.47.7';
-}
+
+our $VERSION = 0.26;
 
 use Gtk2 '-init';
 
@@ -24,7 +23,6 @@ use Gapp::Form::Context;
 use Gapp::Form::Stash;
 use Gapp::Frame;
 use Gapp::HBox;
-use Gapp::HPaned;
 use Gapp::HButtonBox;
 use Gapp::Image;
 use Gapp::ImageMenuItem;
@@ -34,36 +32,27 @@ use Gapp::Menu;
 use Gapp::MenuBar;
 use Gapp::MenuItem;
 use Gapp::MenuToolButton;
-use Gapp::Model::List;
-use Gapp::Model::SimpleList;
+use Gapp::Notice;
+use Gapp::NoticeBox;
 use Gapp::ProgressBar;
 use Gapp::RadioButton;
 use Gapp::ScrolledWindow;
 use Gapp::SeparatorMenuItem;
 use Gapp::SeparatorToolItem;
 use Gapp::SpinButton;
-use Gapp::Model::SimpleList;
-use Gapp::Notebook;
-use Gapp::Statusbar;
+use Gapp::SimpleList;
 use Gapp::StatusIcon;
 use Gapp::SSNEntry;
 use Gapp::Table;
-use Gapp::TextBuffer;
-use Gapp::TextTag;
-use Gapp::TextTagTable;
-use Gapp::TextView;
 use Gapp::TimeEntry;
 use Gapp::ToggleButton;
 use Gapp::Toolbar;
 use Gapp::ToolButton;
-use Gapp::ToolItemGroup;
-use Gapp::ToolPalette;
+use Gapp::TextView;
 use Gapp::TreeView;
 use Gapp::TreeViewColumn;
 use Gapp::UIManager;
 use Gapp::VBox;
-use Gapp::Viewport;
-use Gapp::VPaned;
 use Gapp::VButtonBox;
 use Gapp::Widget;
 use Gapp::Window;
@@ -71,12 +60,13 @@ use Gapp::Window;
 
 use Gapp::Layout::Default;
 our $Layout = Gapp::Layout::Default->Layout;
-use Gapp::Meta::Widget::Native::Role::FormField;
 
-use Gapp::Meta::Widget::Native::Trait::AssistantPage;
+use Gapp::Meta::Widget::Native::Trait::ErrorDialog;
 use Gapp::Meta::Widget::Native::Trait::Form;
+use Gapp::Meta::Widget::Native::Trait::FormField;
 use Gapp::Meta::Widget::Native::Trait::FromUIManager;
-use Gapp::Meta::Widget::Native::Trait::NotebookPage;
+use Gapp::Meta::Widget::Native::Trait::MessageDialog;
+use Gapp::Meta::Widget::Native::Trait::OkCancelDialog; # deprecated
 use Gapp::Meta::Widget::Native::Trait::TreeViewListFormField;
 use Gapp::Meta::Widget::Native::Trait::TreeViewToggleListFormField;
 
@@ -113,8 +103,6 @@ Gapp - Post-modern Gtk+ applications
             )
         ]
     );
-    
-    $w->show_all;
 
     Gapp->main;
   
@@ -126,15 +114,11 @@ COMPLETE IN THEIR IMPLEMENTATION. THE DOCUMENTATION MAY ALSO BE LACKING.*
     
 =head1 DESCRIPTION
 
-Gapp brings the I<post-modern> feel of L<Moose> to Gtk2-Perl applications.
+Gapp is a framework for building GUI applications.
 
-The primary goal of Gapp is to make Perl 5 GUI programming easier and less
-tedious. With Gapp you can to think more about what you want to do and less
-about choreographing widgets or keeping them (and your data) up to date.
-
-Gapp applicationss maintain a consistent look and feel without the need to hand
--configure every widget. Gapp effectively separates GUI design from application
-logic and data structures, while keeping your widgets and data up-to-date.
+The main goal of Gapp is to make Perl 5 GUI programming easier and less tedious.
+With Gapp you can to think more about what you want to do and less about
+choreographing widgets or keeping them (and your data) up to date.
 
 =head2 New to Gapp?
 
@@ -157,29 +141,33 @@ Delegates to C<Gtk2::main_quit>.
 =head1 ACKNOWLEDGEMENTS
 
 Thanks to everyone at Gtk2-Perl and Moose and all those who came before me for
-making this module possible. Thanks to Jrn Reder and the authors and contributors
-of C<MooseX::Types>.
+making this module possible.
 
-C<Gapp::TableMap> uses code from Jrn Reder's L<Gtk2::Ex::FormFactory::Table>
-(see L<Gapp::TableMap> for more details.)
+Special thanks to Jrn Reder, author of L<Gtk2::Ex::FormFactory>, which inspired
+me to write Gapp. L<Gapp::TableMap> uses modified code directly from
+L<Gtk2::Ex::FormFactory::Table> (see L<Gapp::TableMap> for more details.)
 
-C<Gapp::Actions> is based off of L<MooseX::Types> (see L<Gapp::Actions> for more details.)
+Special thanks to the authors and contributors of L<MooseX::Types>, which formed
+the basis for L<Gapp::Actions> (see L<Gapp::Actions> for more details.)
 
 =head1 AUTHORS
 
 Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
 
+Individual packages in this module may have have multiple authors/and or
+contributors. Please refer to the documentation of indivdual packages for
+more information. (see L<Gapp::Actions>, L<Gapp::TableMap>)
+
 =head1 COPYRIGHT & LICENSE
 
-Copyright (c) 2010-2012 Jeffrey Ray Hallock.
+    Copyright (c) 2011 Jeffrey Ray Hallock.
     
-    This is free software, licensed under:
-
-    The Artistic License 2.0 (GPL Compatible)
+    This program is free software; you can redistribute it and/or
+    modify it under the same terms as Perl itself.
     
-Individual files in this package may have have multiple copyrights and/or
-licenses. Please refer to the documentation of indivdual packages for more
-information. (see L<Gapp::Actions>, L<Gapp::TableMap>)
+    Individual packages in this module may have have multiple copyrights and
+    licenses. Please refer to the documentation of indivdual packages for more
+    information. (see L<Gapp::Actions>, L<Gapp::TableMap>)
 
 =cut
 
