@@ -1,14 +1,11 @@
 package Gapp::Box;
-{
-  $Gapp::Box::VERSION = '0.47.7';
-}
 
 use Moose;
 use MooseX::SemiAffordanceAccessor;
 
 extends 'Gapp::Container';
 
-has '+gclass' => (
+has '+class' => (
     default => 'Gtk2::Box',
 );
 
@@ -16,10 +13,15 @@ sub BUILDARGS {
     my $class = shift;
     my %args = @_ == 1 && is_HashRef( $_[0] ) ? %{$_[0]} : @_;
     
-    for my $att ( qw[spacing homogeneous] ) {
-        $args{properties}{$att} = delete $args{$att} if exists $args{$att};
+    if ( exists $args{spacing} ) {
+        $args{properties}{spacing} = $args{spacing};
+        delete $args{spacing};
     }
-
+    if ( exists $args{homogeneous} ) {
+        $args{properties}{homogeneous} = $args{homogeneous};
+        delete $args{homogeneous};
+    }
+    
     __PACKAGE__->SUPER::BUILDARGS( %args );
 }
 
@@ -38,13 +40,11 @@ Gapp::Box - Box widget
 
 =over 4
 
-=item L<Gapp::Object>
+=item L<Gapp::Widget>
 
-=item +-- L<Gapp::Widget>
+=item +-- L<Gapp::Container>
 
-=item ....+-- L<Gapp::Container>
-
-=item ........+-- Gapp::Box
+=item ....+-- L<Gapp::Box>
 
 =back
 
@@ -64,7 +64,7 @@ Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
 
 =head1 COPYRIGHT & LICENSE
 
-    Copyright (c) 2011-2012 Jeffrey Ray Hallock.
+    Copyright (c) 2011 Jeffrey Ray Hallock.
 
     This program is free software; you can redistribute it and/or
     modify it under the same terms as Perl itself.
