@@ -1,7 +1,4 @@
 package Gapp::DateEntry;
-{
-  $Gapp::DateEntry::VERSION = '0.47.7';
-}
 
 use Moose;
 use MooseX::SemiAffordanceAccessor;
@@ -9,8 +6,9 @@ use MooseX::SemiAffordanceAccessor;
 use Gapp::Gtk2::DateEntry;
 
 extends 'Gapp::Entry';
+with 'Gapp::Meta::Widget::Native::Trait::FormField';
 
-has '+gclass' => (
+has '+class' => (
     default => 'Gapp::Gtk2::DateEntry',
 );
 
@@ -19,8 +17,9 @@ sub BUILDARGS {
     my $class = shift;
     my %args = @_ == 1 && is_HashRef( $_[0] ) ? %{$_[0]} : @_;
     
-    for my $att ( qw(value) ) {
-        $args{properties}{$att} = delete $args{$att} if exists $args{$att};
+    if ( exists $args{value} ) {
+        $args{properties}{value} = $args{value};
+        delete $args{value};
     }
 
     __PACKAGE__->SUPER::BUILDARGS( %args );
@@ -28,18 +27,18 @@ sub BUILDARGS {
 
 # returns the value of the widget
 sub get_field_value {
-    $_[0]->gobject->get_value;
+    $_[0]->gtk_widget->get_value;
 }
 
 sub set_field_value {
     my ( $self, $value ) = @_;
-    $self->gobject->set_value( $value );
+    $self->gtk_widget->set_value( $value );
 }
 
 sub _connect_changed_handler {
     my ( $self ) = @_;
 
-    $self->gobject->signal_connect (
+    $self->gtk_widget->signal_connect (
       'value-changed' => sub { $self->_widget_value_changed },
     );
 }
@@ -60,23 +59,23 @@ Gapp::DateEntry - DateEntry Widget
 
 =over 4
 
-=item L<Gapp::Object>
+=item L<Gapp::Widget>
 
-=item +-- L<Gapp::Widget>
+=item +-- L<Gapp::Entry>
 
-=item ....+-- L<Gapp::Entry>
-
-=item ........+-- L<Gapp::DateEntry>
+=item ----+-- L<Gapp::DateEntry>
 
 =back
 
-=head1 DELEGATED PROPERTIES
+=head1 DELEGATES TO GTK
+
+=head2 Attributes
 
 =over 4
 
-=item value
+=item B<value>
 
-=back
+=back 
 
 =head1 AUTHORS
 
@@ -84,7 +83,7 @@ Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
 
 =head1 COPYRIGHT & LICENSE
 
-    Copyright (c) 2011-2012 Jeffrey Ray Hallock.
+    Copyright (c) 2011 Jeffrey Ray Hallock.
 
     This program is free software; you can redistribute it and/or
     modify it under the same terms as Perl itself.
