@@ -1,15 +1,12 @@
 package Gapp::Entry;
-{
-  $Gapp::Entry::VERSION = '0.47.7';
-}
 
 use Moose;
 use MooseX::SemiAffordanceAccessor;
 
 extends 'Gapp::Widget';
-with 'Gapp::Meta::Widget::Native::Role::FormField';
+with 'Gapp::Meta::Widget::Native::Trait::FormField';
 
-has '+gclass' => (
+has '+class' => (
     default => 'Gtk2::Entry',
 );
 
@@ -17,21 +14,27 @@ sub BUILDARGS {
     my $class = shift;
     my %args = @_ == 1 && is_HashRef( $_[0] ) ? %{$_[0]} : @_;
     
-    for my $att ( qw(text xalign width_chars) ) {
-        $args{properties}{$att} = delete $args{$att} if exists $args{$att};
+    if ( exists $args{text} ) {
+        $args{properties}{text} = [ $args{text} ];
+        delete $args{text};
+    }
+    if ( exists $args{xalign} ) {
+        $args{properties}{xalign} = delete $args{xalign};
+    }
+    if ( exists $args{width_chars} ) {
+        $args{properties}{width_chars} = delete $args{width_chars};
     }
-
     __PACKAGE__->SUPER::BUILDARGS( %args );
 }
 
 # returns the value of the widget
 sub get_field_value {
-    $_[0]->gobject->get_text;
+    $_[0]->gtk_widget->get_text;
 }
 
 sub set_field_value {
     my ( $self, $value ) = @_;
-    $self->gobject->set_text( defined $value ? $value : '' );
+    $self->gtk_widget->set_text( defined $value ? $value : '' );
 }
 
 sub widget_to_stash {
@@ -47,7 +50,7 @@ sub stash_to_widget {
 sub _connect_changed_handler {
     my ( $self ) = @_;
 
-    $self->gobject->signal_connect (
+    $self->gtk_widget->signal_connect (
       changed => sub { $self->_widget_value_changed },
     );
 }
@@ -67,11 +70,9 @@ Gapp::Entry - Entry Widget
 
 =over 4
 
-=item L<Gapp::Object>
+=item L<Gapp::Widget>
 
-=item +-- L<Gapp::Widget>
-
-=item ....+-- L<Gapp::Entry>
+=item +-- L<Gapp::Entry>
 
 =back
 
@@ -79,11 +80,27 @@ Gapp::Entry - Entry Widget
 
 =over 4
 
-=item L<Gapp::Meta::Widget::Native::Role::FormField>
+=item L<Gapp::Meta::Widget::Native::Trait::FormField>
 
 =back
 
-=head1 DELEGATED PROPERTIES
+=head1 PROVIDED ATTRIBUTES
+
+=over 4
+
+=item B<buttons>
+
+=over 4
+
+=item isa ArrayRef
+
+=back
+
+=back
+
+=head1 DELEGATES TO GTK
+
+=head2 Attributes
 
 =over 4
 
@@ -99,7 +116,7 @@ Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
 
 =head1 COPYRIGHT & LICENSE
 
-    Copyright (c) 2011-2012 Jeffrey Ray Hallock.
+    Copyright (c) 2011 Jeffrey Ray Hallock.
 
     This program is free software; you can redistribute it and/or
     modify it under the same terms as Perl itself.
