@@ -1,7 +1,4 @@
 package Gapp::FileChooserDialog;
-{
-  $Gapp::FileChooserDialog::VERSION = '0.47.7';
-}
 
 use Moose;
 use MooseX::SemiAffordanceAccessor;
@@ -9,26 +6,26 @@ use MooseX::Types::Moose qw( ArrayRef );
 
 extends 'Gapp::Dialog';
 
-has '+gclass' => (
+has '+class' => (
     default => 'Gtk2::FileChooserDialog',
 );
 
-has '+gobject' => (
+has '+gtk_widget' => (
     handles => ['run'],
 );
 
-has '+parent' => (
-    is => 'rw',
-    isa => 'Maybe[Object]',
-    default => undef,
-);
-
 has 'action' => (
     is => 'rw',
     isa => 'Str',
     default => 'open',
 );
 
+has '+parent' => (
+    is => 'rw',
+    isa => 'Maybe[Object]',
+    default => undef,
+);
+
 has 'filters' => (
     isa => 'ArrayRef',
     default => sub { [] },
@@ -41,10 +38,10 @@ has 'filters' => (
 
 
 
-before '_build_gobject' => sub {
+before '_build_gtk_widget' => sub {
     my $self = shift;
     $self->set_args( [ $self->properties->{title} ? $self->properties->{title} : '' ,
-                      $self->parent ? $self->parent->gobject : undef,
+                      $self->parent ? $self->parent->gtk_widget : undef,
                       $self->action ] );
 };
     
@@ -58,23 +55,21 @@ __END__
 
 =head1 NAME
 
-Gapp::FileChooserDialog - FileChooserDialog Widget
+Gapp::FileChooserDialog - Dialog Widget
 
 =head1 OBJECT HIERARCHY
 
 =over 4
 
-=item L<Gapp::Object>
+=item L<Gapp::Widget>
 
-=item +-- L<Gapp::Widget>
+=item +-- L<Gapp::Container>
 
-=item ....+-- L<Gapp::Container>
+=item ....+-- L<Gapp::Window>
 
-=item ........+-- L<Gapp::Window>
+=item ........+-- L<Gapp::Dialog>
 
-=item ............+-- L<Gapp::Dialog>
-
-=item ................+-- L<Gapp::FileChooserDialog>
+=item ............+-- L<Gapp::FileChooserDialog>
 
 =back
 
@@ -86,32 +81,20 @@ Gapp::FileChooserDialog - FileChooserDialog Widget
 
 =over 4
 
-=item is rw
-
 =item isa Str
 
-=item default open
-
 =back
 
-Describes whether the C<FileChooser> is being used to open an existing file
-or to save to a possibly new file. The available options are: C<open>, C<save>,
-C<select-folder>, C<create-folder>.
-
 =back
 
 =item B<filters>
 
 =over 4
 
-=item is rw
-
-=item isa ArrayRef[L<Gapp::FileFilter>]
+=item isa Array
 
 =back
 
-The file filters available to the user in the dialog.
-
 =back
 
 =head1 AUTHORS
@@ -120,7 +103,7 @@ Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
 
 =head1 COPYRIGHT & LICENSE
 
-    Copyright (c) 2011-2012 Jeffrey Ray Hallock.
+    Copyright (c) 2011 Jeffrey Ray Hallock.
 
     This program is free software; you can redistribute it and/or
     modify it under the same terms as Perl itself.
