@@ -1,12 +1,9 @@
 package Gapp::HBox;
-{
-  $Gapp::HBox::VERSION = '0.47.7';
-}
 
 use Moose;
 extends 'Gapp::Box';
 
-has '+gclass' => (
+has '+class' => (
     default => 'Gtk2::HBox',
 );
 
@@ -24,15 +21,13 @@ Gapp::HBox - HBox Widget
 
 =over 4
 
-=item L<Gapp::Object>
+=item L<Gapp::Widget>
 
-=item +-- L<Gapp::Widget>
+=item +-- L<Gapp::Container>
 
-=item ....+-- L<Gapp::Container>
+=item ....+-- L<Gapp::Box>
 
-=item ........+-- L<Gapp::Box>
-
-=item ............+-- L<Gapp::HBox>
+=item ........+-- L<Gapp::HBox>
 
 =back
 
@@ -42,7 +37,7 @@ Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
 
 =head1 COPYRIGHT & LICENSE
 
-    Copyright (c) 2011-2012 Jeffrey Ray Hallock.
+    Copyright (c) 2011 Jeffrey Ray Hallock.
 
     This program is free software; you can redistribute it and/or
     modify it under the same terms as Perl itself.
