@@ -1,14 +1,11 @@
 package Gapp::Image;
-{
-  $Gapp::Image::VERSION = '0.47.7';
-}
 
 use Moose;
 use MooseX::SemiAffordanceAccessor;
 
 extends 'Gapp::Widget';
 
-has '+gclass' => (
+has '+class' => (
     default => 'Gtk2::Image',
 );
 
@@ -34,11 +31,9 @@ Gapp::Image - Image Widget
 
 =over 4
 
-=item L<Gapp::Object>
+=item L<Gapp::Widget>
 
-=item +-- L<Gapp::Widget>
-
-=item ....+-- L<Gapp::Image>
+=item +-- L<Gapp::Image>
 
 =back
 
@@ -46,20 +41,14 @@ Gapp::Image - Image Widget
 
 =over 4
 
-=item B<stock [$stock_id, $size]>
+=item B<stock>
 
 =over 4
 
-=item is rw
-
 =item isa ArrayRef
 
-=item default []
-
 =back
 
-The stock item to create the image from.
-
 =back
 
 =head1 AUTHORS
@@ -68,7 +57,7 @@ Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
 
 =head1 COPYRIGHT & LICENSE
 
-    Copyright (c) 2011-2012 Jeffrey Ray Hallock.
+    Copyright (c) 2011 Jeffrey Ray Hallock.
 
     This program is free software; you can redistribute it and/or
     modify it under the same terms as Perl itself.
