@@ -1,15 +1,12 @@
 package Gapp::Layout;
-{
-  $Gapp::Layout::VERSION = '0.47.7';
-}
 use strict;
 use warnings;
 
 use Gapp::Layout::Object;
 
 use Sub::Exporter -setup => {
-    exports => [qw/Layout build add to extends paint style/],
-    groups  => { default => [qw/Layout build add to extends paint style/] },
+    exports => [qw/Layout build add to extends style/],
+    groups  => { default => [qw/Layout build add to extends style/] },
 };
 
 {
@@ -39,10 +36,6 @@ sub extends {
     caller()->Layout->set_parent( $base->Layout );
 }
 
-sub paint {
-    my ( $type, $definition ) = @_;
-    caller()->Layout->add_painter( $type => $definition );
-}
 
 sub style {
     my ( $type, $definition ) = @_;
@@ -72,52 +65,32 @@ Gapp::Layout - Define how widgets are displayed
 =head1 SYNOPSIS
 
     package My::Custom::Layout;
-
     use Gapp::Layout;
-
     extends 'Gapp::Layout::Default';
-
-
+    
     # center all entry texts
-
     style 'Gapp::Entry', sub {
-
         ( $layout, $widget ) = @_;
-
         $widget->properties->{xalign} ||= .5 ;
-
         $layout->parent->style_widget( $widget );
-
     };
     
     # add a widget to bottom of all vboxes
     build 'Gapp::VBox', sub {
-
         ( $layout, $widget ) = @_;
-
-        $footer  = Gtk2::Label->new( 'footer!, 0, 0, 0 );
-
-        $widget->gobject->pack_end( $footer,  );
-
+        $footer  = Gtk2::Label->new( 'footer!, 0, 0, 0 );        
+        $widget->gtk_widget->pack_end( $footer,  );
         $layout->parent->build_widget( $widget );
-
     };
     
     # specify how buttons are packed into a button box
     add 'Gapp::Button', to 'Gapp::HButtonBox', sub {
-
         my ($l, $w, $c) = @_;
-
-        $c->gobject->pack_end(
-
-            $w->gobject,
-    
+        $c->gtk_widget->pack_end(
+            $w->gtk_widget,
             $w->expand,
-    
             $w->fill,
-    
             $w->padding
-    
         );
     };
   
@@ -137,11 +110,8 @@ A layout is defined in a package. It is recomended that you inherit from
 L<Gapp::Layout::Default>.
  
  package My::Custom::Layout;
-
  use Gapp::Layout;
-
  extends 'Gapp::Layout::Default';
-
  
 =head2 Stylers
 
@@ -173,7 +143,7 @@ builder to maniplulate things at the Gtk2 level.
 
         $footer  = Gtk2::Label->new( 'footer!, 0, 0, 0 );
 
-        $widget->gobject->pack_end( $footer,  );
+        $widget->gtk_widget->pack_end( $footer,  );
 
         $layout->parent->build_widget( $widget );
 
@@ -184,71 +154,42 @@ builder to maniplulate things at the Gtk2 level.
 Packers are used to position widgets in containers. 
 
     # specify how buttons are packed into a button box
-
     add 'Gapp::Button', to 'Gapp::HButtonBox', sub {
-
         my ( $layout, $widget, $container ) = @_;
-
-        $container->gobject->pack_end(
-
-            $widget->gobject,
-
+        $container->gtk_widget->pack_end(
+            $widget->gtk_widget,
             $widget->expand,
-
             $widget->fill,
-
             $widget->padding
-
         );
-
     };
     
-The example above defines the packing rules for a very specific case - how a L<Gapp::Button>
-is packed into a L<Gapp::HbuttonBox>, but you can define something much more general.
-The example below demonstrates a more general use packing rule, determining how an L<Gapp::Widget>
-should be displayed in a L<Gapp::VBox>. 
-
-    # widgets always fill/expand vboxes
+The above example is pretty specific, but you can define something much more
+general. Take the example below:
 
+    # widgets always fill/expand vboxs
     add 'Gapp::Widget', to 'Gapp::VBox', sub {
-
         my ( $layout, $widget, $container ) = @_;
-
-        $container->gobject->pack_end(
-
-            $widget->gobject,
-
-            $widget->expand,
-
-            $widget->fill,
-
+        $container->gtk_widget->pack_end(
+            $widget->gtk_widget,
+            1,
+            1, #fill
             $widget->padding
-
         );
-
     };
 
 This will make any L<Gapp::Widget> in a L<Gapp::VBox> expand and fill. You could
 then override this, for a specific widget:
 
     # widgets always fill/expand vboxs
-
-    add 'Gapp::Widget', to 'Gapp::VBox', sub {
-
+    add 'Gapp::Button', to 'Gapp::VBox', sub {
         my ( $layout, $widget, $container ) = @_;
-
-        $container->gobject->pack_end(
-
-            $widget->gobject,
-
-            1,
-
-            1, #fill
-
+        $container->gtk_widget->pack_end(
+            $widget->gtk_widget,
+            $widget->expand,
+            $widget->fill,
             $widget->padding
-
         );
-
     };
 
 =head1 EXPORTED FUNCTIONS
@@ -263,14 +204,10 @@ Set the packer for this widget\container combination.
 
 Set the builder for this widget.
 
-=item B<extends $layout_class>
+=item B<extends $class>
 
 Use this if you want to subclass another layout.
 
-=item B<style $widget_class, \&style_func >
-
-Set the styler for this widget.
-
 =back
 
 =head1 AUTHOR
@@ -279,7 +216,7 @@ Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
 
 =head1 COPYRIGHT
 
-    Copyright (c) 2011-2012 Jeffrey Ray Hallock.
+    Copyright (c) 2011 Jeffrey Ray Hallock.
     This program is free software; you can redistribute it and/or
     modify it under the same terms as Perl itself.
 
