@@ -1,13 +1,10 @@
 package Gapp::MenuBar;
-{
-  $Gapp::MenuBar::VERSION = '0.47.7';
-}
 
 use Moose;
 use MooseX::SemiAffordanceAccessor;
 extends 'Gapp::MenuShell';
 
-has '+gclass' => (
+has '+class' => (
     default => 'Gtk2::MenuBar',
 );
 
@@ -28,15 +25,13 @@ Gapp::MenuBar - MenuBar Widget
 
 =over 4
 
-=item L<Gapp::Object>
+=item L<Gapp::Widget>
 
-=item +-- L<Gapp::Widget>
+=item +-- L<Gapp::Container>
 
-=item ....+-- L<Gapp::Container>
+=item ....+-- L<Gapp::MenuShell>
 
-=item ........+-- L<Gapp::MenuShell>
-
-=item ............+-- L<Gapp::MenuBar>
+=item ........+-- L<Gapp::MenuBar>
 
 =back
 
@@ -46,7 +41,7 @@ Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
 
 =head1 COPYRIGHT & LICENSE
 
-    Copyright (c) 2011-2012 Jeffrey Ray Hallock.
+    Copyright (c) 2011 Jeffrey Ray Hallock.
 
     This program is free software; you can redistribute it and/or
     modify it under the same terms as Perl itself.
