@@ -1,21 +1,22 @@
 package Gapp::MenuToolButton;
-{
-  $Gapp::MenuToolButton::VERSION = '0.47.7';
-}
 
 use Moose;
 use MooseX::SemiAffordanceAccessor;
 extends 'Gapp::ToolButton';
-with 'Gapp::Meta::Widget::Native::Role::HasMenu';
 
-has '+gclass' => (
+has '+class' => (
     default => 'Gtk2::MenuToolButton',
 );
 
-#after '_construct_gobject' => sub {
-#    my ( $self ) = @_;
-#    $self->gobject->set_menu( $self->menu->gobject ) if $self->menu;
-#};
+has 'menu' => (
+    is => 'rw',
+    isa => 'Gapp::Menu',
+);
+
+after '_construct_gtk_widget' => sub {
+    my ( $self ) = @_;
+    $self->gtk_widget->set_menu( $self->menu->gtk_widget ) if $self->menu;
+};
 
 1;
 
@@ -33,9 +34,7 @@ Gapp::MenuToolButton - MenuToolButton Widget
 
 =over 4
 
-=item L<Gapp::Object>
-
-=item +-- L<Gapp::Widget>
+=item L<Gapp::Widget>
 
 =item ....+-- L<Gapp::ToolItem>
 
@@ -45,11 +44,17 @@ Gapp::MenuToolButton - MenuToolButton Widget
 
 =back
 
-=head2 Roles
+=head1 PROVIDED ATTRIBUTES
 
 =over 4
 
-=item L<Gapp::Meta::Widget::Native::Role::HasMenu>
+=item B<menu>
+
+=over 4
+
+=item isa GappMenu
+
+=back
 
 =back
 
@@ -59,7 +64,7 @@ Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
 
 =head1 COPYRIGHT & LICENSE
 
-    Copyright (c) 2011-2012 Jeffrey Ray Hallock.
+    Copyright (c) 2011 Jeffrey Ray Hallock.
 
     This program is free software; you can redistribute it and/or
     modify it under the same terms as Perl itself.
