@@ -1,10 +1,6 @@
 package Gapp::Meta::Widget::Native::Trait::FromUIManager;
-{
-  $Gapp::Meta::Widget::Native::Trait::FromUIManager::VERSION = '0.47.7';
-}
 
 use Moose::Role;
-use MooseX::SemiAffordanceAccessor;
 use MooseX::LazyRequire;
 
 use Gapp::Types qw( GappUIManager );
@@ -22,9 +18,9 @@ has 'ui_widget' => (
     lazy_required => 1,
 );
 
-around '_construct_gobject' => sub {
+around '_construct_gtk_widget' => sub {
     my ( $orig, $self ) = @_;
-    my $w = $self->ui->gobject->get_widget( $self->ui_widget );
+    my $w = $self->ui->gtk_widget->get_widget( $self->ui_widget );
     
     if ( ! $w ) {
         $self->meta->throw_error(
@@ -35,7 +31,7 @@ around '_construct_gobject' => sub {
         )
     }
     else {
-        $self->set_gobject( $w );
+        $self->set_gtk_widget( $w );
         return $w;
     }
     
@@ -43,9 +39,6 @@ around '_construct_gobject' => sub {
 
 
 package Gapp::Meta::Widget::Custom::Trait::FromUIManager;
-{
-  $Gapp::Meta::Widget::Custom::Trait::FromUIManager::VERSION = '0.47.7';
-}
 sub register_implementation { 'Gapp::Meta::Widget::Native::Trait::FromUIManager' };
 
 
