@@ -1,18 +1,23 @@
 package Gapp::StatusIcon;
-{
-  $Gapp::StatusIcon::VERSION = '0.47.7';
-}
 
 use Moose;
 use MooseX::SemiAffordanceAccessor;
 
+use Gapp::Types qw( GappActionOrArrayRef );
+use MooseX::Types::Moose qw( Undef );
 
 extends 'Gapp::Widget';
 
-has '+gclass' => (
+has '+class' => (
     default => 'Gtk2::StatusIcon',
 );
 
+#has 'action' => (
+#    is => 'rw',
+#    isa => GappActionOrArrayRef|Undef,
+#);
+
+
 sub BUILDARGS {
     my $class = shift;
     my %args = @_ == 1 && is_HashRef( $_[0] ) ? %{$_[0]} : @_;
@@ -38,17 +43,12 @@ __END__
 
 =head1 NAME
 
-Gapp::StatusIcon - StatusIcon Widget
+Gapp::StatusIcon - Box widget
 
 =head1 OBJECT HIERARCHY
 
-=item L<Gapp::Object>
-
-=item +-- L<Gapp::Widget>
-
-=item ....+-- L<Gapp::StatusIcon>
-
-=head1 DELEGATED
+    Gapp::Widget
+    +--Gapp::StatusIcon
 
 =head1 AUTHORS
 
@@ -56,7 +56,7 @@ Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
 
 =head1 COPYRIGHT & LICENSE
 
-    Copyright (c) 2011-2012 Jeffrey Ray Hallock.
+    Copyright (c) 2011 Jeffrey Ray Hallock.
 
     This program is free software; you can redistribute it and/or
     modify it under the same terms as Perl itself.
