@@ -1,7 +1,4 @@
 package Gapp::Table;
-{
-  $Gapp::Table::VERSION = '0.47.7';
-}
 
 
 use Moose;
@@ -13,7 +10,7 @@ extends 'Gapp::Container';
 use Gapp::TableMap;
 use Gapp::Types qw( GappTableMap );
 
-has '+gclass' => (
+has '+class' => (
     default => 'Gtk2::Table',
 );
 
@@ -44,7 +41,7 @@ sub next_cell {
 }
 
 
-before _construct_gobject => sub {
+before _construct_gtk_widget => sub {
 	my $self = shift;
 	return $self->set_args( [ $self->map->row_count, $self->map->col_count, 0 ] );
 };
@@ -112,7 +109,7 @@ See L<Gapp::TableMap> for more information on drawing tables.
 
 =item isa: L<Gapp::TableMap>
 
-=item coercions: Str
+=item coerceions: Str
 
 =back
 
@@ -124,7 +121,7 @@ Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
 
 =head1 COPYRIGHT & LICENSE
 
-    Copyright (c) 2011-2012 Jeffrey Ray Hallock.
+    Copyright (c) 2011 Jeffrey Ray Hallock.
 
     This program is free software; you can redistribute it and/or
     modify it under the same terms as Perl itself.
