@@ -1,19 +1,16 @@
 package Gapp::TreeViewColumn;
-{
-  $Gapp::TreeViewColumn::VERSION = '0.47.7';
-}
 
 use Moose;
-extends 'Gapp::Object';
+extends 'Gapp::Widget';
 
 use Gapp::CellRenderer;
 use Gapp::Util;
 use Gapp::Types qw( GappCellRenderer GappTreeViewColumn );
 
 use Moose::Util;
-use MooseX::Types::Moose qw( Str ArrayRef HashRef CodeRef Undef );
+use MooseX::Types::Moose qw( Str ArrayRef HashRef CodeRef );
 
-has '+gclass' => (
+has '+class' => (
     default => 'Gtk2::TreeViewColumn',
 );
 
@@ -25,15 +22,15 @@ has 'name' => (
 
 has 'renderer' => (
     is => 'rw',
-    isa => GappCellRenderer|Undef,
-    default => sub { Gapp::CellRenderer->new( gclass => 'Gtk2::CellRendererText', property => 'markup' ) },
+    isa => GappCellRenderer,
+    default => sub { Gapp::CellRenderer->new( class => 'Gtk2::CellRendererText', property => 'markup' ) },
     coerce => 1,
 );
 
 has 'data_column' => (
     is => 'rw',
     isa => 'Int|Undef',
-    default => 0,
+    default => undef,
 );
 
 has 'data_func' => (
@@ -47,10 +44,10 @@ has 'sort_enabled' => (
     default => 0,
     trigger => sub {
         my ( $self ) = @_;
-        if ( $self->has_gobject ) {
-            $self->gobject->set_clickable( 1 );
-            $self->gobject->signal_connect( 'clicked', sub {
-                $self->gobject->get_tree_view->get_model->set_default_sort_func( sub {
+        if ( $self->has_gtk_widget ) {
+            $self->gtk_widget->set_clickable( 1 );
+            $self->gtk_widget->signal_connect( 'clicked', sub {
+                $self->gtk_widget->get_tree_view->get_model->set_default_sort_func( sub {
                     my ( $model, $itera, $iterb, $self ) = @_;
                     my $a = $model->get( $itera, $self->data_column );
                     my $b = $model->get( $iterb, $self->data_column );
@@ -67,7 +64,8 @@ has 'sort_func' => (
     default => sub {
         sub {
             my ( $self, $a, $b ) = @_;
-            lc $self->get_cell_value( $a ) cmp lc $self->get_cell_value( $b );
+            print $self->get_cell_value( $a ), " cmp ",  $self->get_cell_value( $b ), "\n";
+            lc $self->get_cell_value( $a ) cmp lc $self->get_cell_value( $b )
         };
     },
 );
@@ -77,12 +75,10 @@ sub BUILDARGS {
     my $class = shift;
     my %args = @_ == 1 && is_HashRef( $_[0] ) ? %{$_[0]} : @_;
     
-    
-    for my $att ( qw(alignment clickable expand fixed_width min_width reordable resizable sizing),
-                  qw(sort_column_id sort_indicator sort_order spacing title visible width') ) {
-        $args{properties}{$att} = delete $args{$att} if exists $args{$att};
+    if ( exists $args{title} ) {
+        $args{properties}{title} = $args{title};
+        delete $args{title};
     }
-    
     __PACKAGE__->SUPER::BUILDARGS( %args );
 }
 
@@ -120,7 +116,7 @@ Gapp::TreeViewColumn - TreeViewColumn Widget
 
 =over 4
 
-=item L<Gapp::Object>
+=item L<Gapp::Widget>
 
 =item +-- L<Gapp::TreeViewColumn>
 
@@ -140,10 +136,6 @@ Gapp::TreeViewColumn - TreeViewColumn Widget
 
 =back
 
-The column in the model that to pull data from. This is what will be displayed within the
-renderer. You can use the C<data_func> attribute to manipulate the data before it is rendered
-in the cell.
-
 =item B<data_func>
 
 =over 4
@@ -152,10 +144,6 @@ in the cell.
 
 =back
 
-Use this to manipulate the data from C<data_column> before rendering it in the cell. The return value
-is what will be passed to the renderer. The <$_> variable will be set to the data from C<data_column>
-within the callback.
-
 =item B<name>
 
 =over 4
@@ -166,50 +154,34 @@ within the callback.
 
 =back
 
-By naming your column you can use C<$treeview->find_column( $name )> to retrieve them later.
-
 =item B<renderer>
 
 =over 4
 
 =item isa: L<Gapp::CellRenderer>
 
-=item default: Gapp::CellRenderer->new( gclass => 'Gtk2::CellRendererText', property => 'markup' );
+=item default: Gapp::CellRenderer->new( class => 'Gtk2::CellRendererText', property => 'markup' );
 
 =back
 
-=head1 DELEGATED PROPERIES
+=item B<values>
 
 =over 4
 
-=item B<alignment>
+=item isa: ArrayRef
 
-=item B<clickable>
+=back
 
-=item B<expand>
+=back
 
-=item B<fixed_width>
+=head1 DELEGATES TO GTK
 
-=item B<min_width>
+=head2 Attributes
 
-=item B<reorderable>
-
-=item B<resizable>
-
-=item B<sizing>
-
-=item B<sort_column_id>
-
-=item B<sort_indicator>
-
-=item B<sort_order>
-
-=item B<spacing>
+=over 4
 
 =item B<title>
 
-=item B<visible_width>
-
 =back 
 
 =head1 AUTHORS
@@ -218,7 +190,7 @@ Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
 
 =head1 COPYRIGHT & LICENSE
 
-    Copyright (c) 2011-2012 Jeffrey Ray Hallock.
+    Copyright (c) 2011 Jeffrey Ray Hallock.
 
     This program is free software; you can redistribute it and/or
     modify it under the same terms as Perl itself.
