@@ -1,12 +1,9 @@
 package Gapp::VBox;
-{
-  $Gapp::VBox::VERSION = '0.47.7';
-}
 
 use Moose;
 extends 'Gapp::Box';
 
-has '+gclass' => (
+has '+class' => (
     default => 'Gtk2::VBox',
 );
 
@@ -27,15 +24,13 @@ Gapp::VBox - VBox Widget
 
 =over 4
 
-=item L<Gapp::Object>
+=item L<Gapp::Widget>
 
-=item +-- L<Gapp::Widget>
+=item +-- L<Gapp::Container>
 
-=item ....+-- L<Gapp::Container>
+=item ....+-- L<Gapp::Box>
 
-=item ........+-- L<Gapp::Box>
-
-=item ............+-- L<Gapp::VBox>
+=item ........+-- L<Gapp::VBox>
 
 =back
 
@@ -45,7 +40,7 @@ Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
 
 =head1 COPYRIGHT & LICENSE
 
-    Copyright (c) 2011-2012 Jeffrey Ray Hallock.
+    Copyright (c) 2011 Jeffrey Ray Hallock.
 
     This program is free software; you can redistribute it and/or
     modify it under the same terms as Perl itself.
